<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:xs="http://www.w3.org/2001/XMLSchema" 
                xmlns:regexp="http://exslt.org/regular-expressions" 
                xmlns:gemfunc="http://www.sunat.gob.pe/gem/functions" 
                xmlns:func="http://exslt.org/functions" 
                xmlns="urn:oasis:names:specification:ubl:schema:xsd:Invoice-2" 
                xmlns:ds="http://www.w3.org/2000/09/xmldsig#" 
                xmlns:ext="urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2" 
                xmlns:sac="urn:sunat:names:specification:ubl:peru:schema:xsd:SunatAggregateComponents-1" 
                xmlns:cbc="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2" 
                xmlns:cac="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2" 
                version="2.0">
    <!-- key Documentos Relacionados Duplicados -->
    <xsl:key name="by-document-despatch-reference" match="cac:DespatchDocumentReference" use="concat(cbc:DocumentTypeCode,' ', cbc:ID)"/>
    <xsl:key name="by-document-additional-reference" match="cac:AdditionalDocumentReference" use="concat(cbc:DocumentTypeCode,' ', cbc:ID)"/>
    <!-- key Documentos Relacionados Duplicados fin -->
    <xsl:key name="by-pricingReference-alternativeConditionPrice-priceTypeCode" match="/cac:PricingReference/cac:AlternativeConditionPrice" use="cbc:PriceTypeCode"/>
    <xsl:template match="/*">
        <!-- Total valor de venta operaciones gravadas operaciones inafectas operaciones 
			exoneradas Operaciones gratuitas Importe de la percepcion en moneda nacional -->
			
        <xsl:variable name="sacAdditionalInformation" select="ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation"/>
        <xsl:variable name="additionalMonetaryTotal" select="$sacAdditionalInformation/sac:AdditionalMonetaryTotal"/>
        <xsl:variable name="additionalMonetaryTotalID" select="$additionalMonetaryTotal/cbc:ID"/>		
        <!-- Tipo de transaccion -->
        <xsl:variable name="sacSUNATTransactionID" select="$sacAdditionalInformation/sac:SUNATTransaction/cbc:ID"/>
		
        <!-- Valida que solo exista un tag  sacAdditionalInformation-->
        <xsl:if test="count($sacAdditionalInformation)>1">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2427)'"/>
            </xsl:message>
        </xsl:if>
       
		<!-- js_140615 _ RF07 traslado de bienes, validacion exclusiva de tags para sacSUNATTransactionID = 06 Inicio -->
        <!-- js_080715	b)Cuando el XML de factura, el tag “/sac:SUNATTransaction/cbc:ID” es diferente a  06 (Factura guía), debe validar lo siguiente:
				b.1  De existir el tag “sac:SUNATEmbededDespatchAdvice”, generar el código de WARNING TEMPORAL EN LUGAR DE ERROR 4047 – sac:SUNATTransaction/cbc:ID debe ser igual a 06 cuando ingrese información para sustentar el traslado.-->
        <xsl:if test="$sacSUNATTransactionID[text() != '06']">
            <xsl:if test="$sacAdditionalInformation/sac:SUNATEmbededDespatchAdvice">
                <xsl:message terminate="no" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 4047)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:if>
        <!-- js_140615 Fin -->
		
		
        <xsl:if test="$sacSUNATTransactionID">
				
            <!--JS 100715 se agrega SUNATTransaction tipo 06 -->
            <!-- De existir el elemento, validar que el campo ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:SUNATTransaction/cbc:ID 
				tenga un valor del catalogo No 17 (01, 02, 03, 04, 05 o  06). Si no cumple, marcar 
				OBS-4042. -->
            <xsl:if test="not($sacSUNATTransactionID[text() = '01' or text() = '02' or text() = '03' or text() = '04' or text() = '05' or text() = '06'])">
                <xsl:message terminate="no" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 4042)'"/>
                </xsl:message>
            </xsl:if>
            <!-- JS 100715 -->
			
			
            <!-- Validaciones a  nivel global -->
            <!-- ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal/cbc:ID-->
            <!-- De ser tipo 04 (anticipos), se debe validar que: Existan los tags: /Invoice/cac:InvoiceLine/cac:Item/cbc:Description 
				y /Invoice/cac:InvoiceLine/cbc:LineExtensionAmount. Si no cumple, marcar como ERROR-2500 -->
            <xsl:if test="$sacSUNATTransactionID[text() = '04'] and not(cac:InvoiceLine/cac:Item/cbc:Description and cac:InvoiceLine/cbc:LineExtensionAmount)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2500)'"/>
                </xsl:message>
            </xsl:if>
			
            <!-- De ser tipo 04 (anticipos), se debe validar que: El tag /Invoice/cac:InvoiceLine/cbc:LineExtensionAmount 
				debe ser mayor que 0. Si no cumple, marcar ERRO -2501 -->
			<xsl:if test="$sacSUNATTransactionID[text() = '04'] and (cac:InvoiceLine/cbc:LineExtensionAmount[text()&lt;=0])">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2501)'"/>
                </xsl:message>
            </xsl:if>
			
			
            <!-- De ser tipo 04 (anticipos) y ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal/cbc:ID 
				es 1001 se debe validar que: El Total IGV (cac:TaxTotal/cbc:TaxAmount), y 
				el Total de la operacion (/Invoice/cac:LegalMonetaryTotal/cbc:PayableAmount). 
				Deben ser mayor a cero. Si no cumple. Marcar como ERROR-2502 -->
            <!-- Tambien se incluyo el error 2502 en un for-each -->
            <xsl:if test="$sacSUNATTransactionID[text() = '04'] and $additionalMonetaryTotalID[text()='1001'] and (cac:TaxTotal/cbc:TaxAmount[text() &lt;=0] or cac:LegalMonetaryTotal/cbc:PayableAmount[text() &lt;=0])">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2502)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:if>
		
		
        <!-- Se incluyo bloque en un For, como en Validador Java - Inicio - PrepaidPayment(Anticipos)-->
        <xsl:for-each select="cac:PrepaidPayment">
            <!-- Validar que si existe informacion en los campos mencionados anteriormente, 
				debe ser numerico mayor a cero. Si no cumple marcar ERROR-2503. Validar que 
				exista el tag de referencia al documento del anticipo. Si no cumple, marcar 
				ERROR-2504 -->
            <!--JorgeS 180315 inicio -->
            <!-- Que el tag monto prepago o anticipado por documento sea mayor a cero. 
			De no cumplir generar código de rechazo 2503 – PaidAmount: monto anticipado por documento debe ser mayor a cero -->
            <!-- <xsl:if test="./cbc:PaidAmount and (not(regexp:match(./cbc:PaidAmount,'^[0-9]{1,12}(\.[0-9]{1,2})?$')) or ./cbc:PaidAmount &lt;= 0 )"> -->
            <xsl:if test="./cbc:PaidAmount and ./cbc:PaidAmount &lt;= 0 ">
                <xsl:message terminate="no" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2503)'"/>
                </xsl:message>
            </xsl:if>
            <!-- Si se encuentra el tag /invoice/cac:PrepaidPayment/cbc:PaidAmount/ 
				validar que existan los tags /invoice/cac:PrepaidPayment/cbc:ID y /invoice/cac:PrepaidPayment/cbc:InstructionID 
				.Si no cumple, marcar ERROR-2504 -->
            <!-- Que existan el documento relacionado con los tag de ruc de emisor que solicita anticipo –de existir, tipo y número de documento de anticipo. 
					De no existir marcar código de error 2504 -  Falta referencia de la factura relacionada con anticipo -->
            <xsl:if test="./cbc:PaidAmount and not(./cbc:ID and ./cbc:InstructionID)">
                <xsl:message terminate="no" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2504)'"/>
                </xsl:message>
            </xsl:if>
            <!-- Validar que el campo /cac:PrepaidPayment/cbc:ID/@SchemeID exista y contenga información. De no corresponder 
			generar código de excepción 1041 - cac:PrepaidPayment/cbc:ID - El tag no contiene el atributo @SchemeID que indica el 
			tipo de documento que realiza el anticipo -->
            <xsl:if test="./cbc:ID/@schemeID and not(./cbc:ID/@schemeID != '')">
                <xsl:message terminate="no" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 1041)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:if test="./cbc:ID and ./cbc:ID/@schemeID !='02' and ./cbc:ID/@schemeID !='03'">
                <xsl:message terminate="no" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2505)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="./cbc:InstructionID/@schemeID">
                    <xsl:if test="not(./cbc:InstructionID/@schemeID != '')">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 1042)'"/>
                        </xsl:message>
                    </xsl:if>
                    
                    <xsl:if test="./cbc:ID/@schemeID ='02' and not(matches(./cbc:ID,'^[F][A-Z0-9]{3}-[0-9]{1,8}$|^(E001)-[0-9]{1,8}$|^[0-9]{1,4}-[0-9]{1,8}$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2521)'"/>
                        </xsl:message>
                    </xsl:if>
                    
                    <!--
                    <xsl:if test="./cbc:ID/@schemeID ='02' and not(regexp:match(./cbc:ID,'^[F][A-Z0-9]{3}-[0-9]{1,8}$|^(E001)-[0-9]{1,8}$|^[0-9]{1,4}-[0-9]{1,8}$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2521)'"/>
                        </xsl:message>
                    </xsl:if>
                    -->
                    
                    <xsl:if test="./cbc:ID/@schemeID ='03' and not(matches(./cbc:ID,'^[B][A-Z0-9]{3}-[0-9]{1,8}$|^[0-9]{1,4}-[0-9]{1,8}$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2521)'"/>
                        </xsl:message>
                    </xsl:if>
                    
                    <!--
                    <xsl:if test="./cbc:ID/@schemeID ='03' and not(regexp:match(./cbc:ID,'^[B][A-Z0-9]{3}-[0-9]{1,8}$|^[0-9]{1,4}-[0-9]{1,8}$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2521)'"/>
                        </xsl:message>
                    </xsl:if>
                    -->
                    
                    <xsl:if test="./cbc:InstructionID/@schemeID != '6'">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2520)'"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test="./cbc:InstructionID = ''">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2529)'"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test="not(matches(./cbc:InstructionID,'^[0-9]{11}$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2521)'"/>
                        </xsl:message>
                    </xsl:if>
                    <!--
                    <xsl:if test="not(regexp:match(./cbc:InstructionID,'^[0-9]{11}$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2521)'"/>
                        </xsl:message>
                    </xsl:if>
                    -->
                </xsl:when>
                <xsl:otherwise>
                    <xsl:if test="./cbc:InstructionID">
                        <xsl:if test="./cbc:InstructionID = ''">
                            <xsl:message terminate="no" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2508)'"/>
                            </xsl:message>
                        </xsl:if>
                        <xsl:if test="not(matches(./cbc:InstructionID,'^[F][A-Z0-9]{3}-[0-9]{1,8}$|^(E001)-[0-9]{1,8}$|^[0-9]{1,4}-[0-9]{1,8}$'))">
                            <xsl:message terminate="no" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 1044)'"/>
                            </xsl:message>
                        </xsl:if>
                        <!--
                        <xsl:if test="not(regexp:match(./cbc:InstructionID,'^[F][A-Z0-9]{3}-[0-9]{1,8}$|^(E001)-[0-9]{1,8}$|^[0-9]{1,4}-[0-9]{1,8}$'))">
                            <xsl:message terminate="no" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 1044)'"/>
                            </xsl:message>
                        </xsl:if>
                        -->
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
        <!-- Se incluyo bloque en un For, como en Validador Java - Fin -->
		
		
        <!-- Se incluye bloque para Errores 2508 y 2509 - Inicio -->
        <xsl:variable name="PrepaidPaymentId02GreaterThan0" select="count(cac:PrepaidPayment/cbc:ID[text()='02'])>0"/>
        <xsl:variable name="acumPrepaid">
        <!--
            <xsl:call-template name="getPrepaidPaymentAcum">
                <xsl:with-param name="Items" select="cac:PrepaidPayment"/>
            </xsl:call-template>
            -->
        </xsl:variable>
  
		<xsl:choose>
		    <xsl:when test="$PrepaidPaymentId02GreaterThan0">
                <xsl:if test="cac:LegalMonetaryTotal/cbc:PrepaidAmount and not(matches(cac:LegalMonetaryTotal/cbc:PrepaidAmount,'^[0-9]{1,12}(\.[0-9]{1,2})?$'))">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2509 -1)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test="cac:LegalMonetaryTotal/cbc:PrepaidAmount and not(regexp:match(cac:LegalMonetaryTotal/cbc:PrepaidAmount,'^[0-9]{1,12}(\.[0-9]{1,2})?$'))">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2509 -1)'"/>
                    </xsl:message>
                </xsl:if>
                -->
                <!--
                <xsl:if test="number(cac:LegalMonetaryTotal/cbc:PrepaidAmount) != number(round(100*$acumPrepaid) div 100)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2509 -2)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='cac:LegalMonetaryTotal/cbc:PrepaidAmount and cac:LegalMonetaryTotal/cbc:PrepaidAmount &lt;= 0'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2508)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
      
        <!-- De existir documento de anticipos se debe validar que exista el tag monto total anticipado. De no corresponder generara 
			el código de excepción 1048 - El XML no contiene el tag o no existe información de PrepaidAmount para documentos con anticipos.-->
        <xsl:if test="cac:LegalMonetaryTotal/cbc:PrepaidAmount and not(cac:LegalMonetaryTotal/cbc:PrepaidAmount !='')">
            <xsl:message terminate="no" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 1048)'"/>
            </xsl:message>
        </xsl:if>
		
        <!-- Que el tag monto total anticipado sea mayor a cero. De no cumplir generar código de error 2527 – PrepaidAmount: monto total 
			anticipado debe ser mayor a cero.-->
        <xsl:if test="cac:LegalMonetaryTotal/cbc:PrepaidAmount and cac:LegalMonetaryTotal/cbc:PrepaidAmount &lt;= 0">
            <xsl:message terminate="no" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2527)'"/>
            </xsl:message>
        </xsl:if>
		
       
        <xsl:choose>
		     <xsl:when test="not(string(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 1006)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID,"^[0-9]{11}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1005)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test='not(regexp:match(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID,"^[0-9]{11}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1005)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
		
		
        <!-- Numeracion, conformada por serie y numero correlativo del comprobante  -->
        <xsl:choose>
            <xsl:when test="not(string(cbc:ID))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 1002)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cbc:ID,"^[F|B][A-Z0-9]{3}-[0-9]{1,8}?$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1001)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test='not(regexp:match(cbc:ID,"^[F][A-Z0-9]{3}-[0-9]{1,8}?$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1001)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
        <!-- <xsl:variable name="errores"> -->
		
        <!-- Tipo Comprobante -->
        <xsl:choose>
            <xsl:when test="not(string(cbc:InvoiceTypeCode))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 1004)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cbc:InvoiceTypeCode,"^[0]{1}[1,3]{1}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1003)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test='not(regexp:match(cbc:InvoiceTypeCode,"^[0]{1}[1]{1}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1003)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
		
        <!-- Version de la Estructura del Documento -->
        <xsl:choose>
            <xsl:when test="not(string(cbc:CustomizationID))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2073)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cbc:CustomizationID,"^[0-9]{1,7}(\.[0-9]{1,2})?$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2072)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test='not(regexp:match(cbc:CustomizationID,"^[0-9]{1,7}(\.[0-9]{1,2})?$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2072)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
     
        <!-- Version del UBL -->
        <xsl:choose>
            <xsl:when test="not(string(cbc:UBLVersionID))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2075)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cbc:UBLVersionID,"^[2]{1}(\.[0]{1})$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2074)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test='not(regexp:match(cbc:UBLVersionID,"^[2]{1}(\.[0]{1})$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2074)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
		    <!-- Ubicacion de pais PE -->	
        <xsl:if test="cac:SellerSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode and cac:SellerSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode != 'PE'">
            <xsl:message terminate="no" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 4041)'"/>
            </xsl:message>
        </xsl:if>
        <!-- Tipo de documento de identidad del emisor - RUC -->
        <xsl:if test="not(string(cac:AccountingSupplierParty/cbc:AdditionalAccountID))">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 1008)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:if test='not(matches(cac:AccountingSupplierParty/cbc:AdditionalAccountID,"^[6]{1}$"))'>
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 1007)'"/>
            </xsl:message>
        </xsl:if>
        <!--
        <xsl:if test='not(regexp:match(cac:AccountingSupplierParty/cbc:AdditionalAccountID,"^[6]{1}$"))'>
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 1007)'"/>
            </xsl:message>
        </xsl:if>
        -->
        <xsl:if test="count(cac:AccountingSupplierParty/cbc:AdditionalAccountID)>1">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2362)'"/>
            </xsl:message>
        </xsl:if>
        <!-- Tipo de moneda en la cual se emite la factura electronica -->
        <xsl:choose>
            <xsl:when test="not(string(cbc:DocumentCurrencyCode))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2070)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cbc:DocumentCurrencyCode,"^[A-Z]{3}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2069)'"/>
                    </xsl:message>
                </xsl:if>
                <!--
                <xsl:if test='not(regexp:match(cbc:DocumentCurrencyCode,"^[A-Z]{3}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2069)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
        
		<!-- Apellidos y nombres o denominacion o razon social Emisor -->
        <xsl:choose>
            <xsl:when test="not(string(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 1037)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <!--<xsl:if test='not(matches(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^(?!\s*$).{3,1000}"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1038)'"/>
                    </xsl:message>
                    </xsl:if>
                    <xsl:if test='not(regexp:match(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^(?!\s*$).{3,1000}"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 1038)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
        
		<!-- Valida que el tipo de documento del adquiriente exista -->
        <xsl:if test="not(string(cac:AccountingCustomerParty/cbc:AdditionalAccountID))">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2015)'"/>
            </xsl:message>
        </xsl:if>
       
	    <!-- Valida que el tipo de documento del adquiriente exista y sea solo uno -->
        <xsl:if test="count(cac:AccountingCustomerParty/cbc:AdditionalAccountID)>1">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2363)'"/>
            </xsl:message>
        </xsl:if>
     
        <!-- Si la operacion no es de exportacion el tipo de documento tiene que ser 6, caso contrario -->
        <xsl:choose>
            <xsl:when test="cac:InvoiceLine/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text()='40']">
                <xsl:if test='not(matches(cac:AccountingCustomerParty/cbc:AdditionalAccountID,"^[01467A\-]{1}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2016)'"/>
                    </xsl:message>
                </xsl:if>
            <!--
                <xsl:if test='not(regexp:match(cac:AccountingCustomerParty/cbc:AdditionalAccountID,"^[01467A\-]{1}$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2016)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(cac:AccountingCustomerParty/cbc:AdditionalAccountID[text()=6 or text()=1])'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2016)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
		
        <!-- Apellidos y nombres o denominacion o razon social del adquirente o usuario -->
        <xsl:choose>
            <xsl:when test="not(string(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2021)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
            <!--
                <xsl:if test='not(matches(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^(?!\s*$).{3,1000}"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2022)'"/>
                    </xsl:message>
                </xsl:if>
                <xsl:if test='not(regexp:match(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^(?!\s*$).{3,1000}"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2022)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
        
		<!-- Importe total de la venta, cesion en uso o del servicio prestado -->
        <xsl:choose>
            <xsl:when test="not(cac:LegalMonetaryTotal/cbc:PayableAmount)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2063)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(cac:LegalMonetaryTotal/cbc:PayableAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2062)'"/>
                    </xsl:message>
                </xsl:if>
            <!--
                <xsl:if test='not(regexp:match(cac:LegalMonetaryTotal/cbc:PayableAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2062)'"/>
                    </xsl:message>
                </xsl:if>
                -->
            </xsl:otherwise>
        </xsl:choose>
       
	   <!-- Sumatoria otros Cargos -->
        <xsl:if test="cac:LegalMonetaryTotal/cbc:ChargeTotalAmount">
            <xsl:if test='not(matches(cac:LegalMonetaryTotal/cbc:ChargeTotalAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2064)'"/>
                </xsl:message>
            </xsl:if>
            <!--
            <xsl:if test='not(regexp:match(cac:LegalMonetaryTotal/cbc:ChargeTotalAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2064)'"/>
                </xsl:message>
            </xsl:if>
            -->
        </xsl:if>
        
		<!-- Descuentos Globales -->
        <xsl:if test="cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount">
            <!-- MOver a la parte del detalle -->
            <xsl:if test='not(matches(cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2065)'"/>
                </xsl:message>
            </xsl:if>
            <!-- fin mover al detalle -->
            <xsl:if test='not(matches(cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2419)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:if>
		
        <!-- Se incluyo bloque en un For, como en Validador Java - Inicio -->
        <xsl:for-each select="cac:DespatchDocumentReference">
            <!-- Documento de referencia -->
            <xsl:if test="./cbc:DocumentTypeCode">
                <xsl:choose>
                    <xsl:when test='not(matches(./cbc:DocumentTypeCode,"^[0-9]{2}$"))'>
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 4004)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="not((./cbc:DocumentTypeCode=09) or (./cbc:DocumentTypeCode=31))">
                          <xsl:message terminate="no" >
                              <xsl:value-of select="'Error Expr Regular Factura (codigo: 4005)'"/>
                          </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
            <xsl:if test="./cbc:DocumentTypeCode">
                <xsl:choose>
                    <xsl:when test='not(./cbc:ID)'>
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 4007)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test='not(matches(./cbc:ID,"^(.){1,}-[0-9]{1,}$"))'>
                            <xsl:message terminate="no" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 4006)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:for-each>
        
		<!-- Se incluyo bloque en un For, como en Validador Java - Fin -->
        <xsl:for-each select="cac:DespatchDocumentReference">
            <xsl:if test="count(key('by-document-despatch-reference', concat(./cbc:DocumentTypeCode,' ',./cbc:ID))) > 1">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura  (codigo: 2364)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:for-each>
             
		    <!-- Se incluyo bloque en un For, como en Validador Java - Inicio -->
        <xsl:for-each select="cac:AdditionalDocumentReference">
            <xsl:if test="./cbc:DocumentTypeCode">
                <xsl:choose>
                    <xsl:when test='not(matches(./cbc:DocumentTypeCode,"^[0-9]{2}$"))'>
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura  (codigo: 4008)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="not((./cbc:DocumentTypeCode=04) or (./cbc:DocumentTypeCode=05) or (./cbc:DocumentTypeCode=99) or (./cbc:DocumentTypeCode=01))">
                            <xsl:message terminate="no" >
                                <xsl:value-of select="'Error Expr Regular Factura  (codigo: 4009)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
            <xsl:choose>
                <xsl:when test='./cbc:DocumentTypeCode and not(./cbc:ID)'>
                    <xsl:message terminate="no" >
                        <xsl:value-of select="'Error Expr Regular Factura  (codigo: 4011)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <!-- INICIO DCERRENO -->
                    <!--<xsl:if test='./cbc:DocumentTypeCode and not(matches(./cbc:ID,"^(?!\s*$).{1,100}"))'>-->
                    <!-- FINAL DCERRENO -->
                    <xsl:if test='./cbc:DocumentTypeCode and not(matches(./cbc:ID,"^(\s*$).{1,100}"))'>
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura  (codigo: 4010)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
       
	   <!-- Se incluyo bloque en un For, como en Validador Java - Fin -->
	    <xsl:for-each select="cac:AdditionalDocumentReference">
            <xsl:if test="count(key('by-document-additional-reference', concat(./cbc:DocumentTypeCode,' ',./cbc:ID))) > 1">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura  (codigo: 2365)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:for-each>
        <!-- Se incluyo bloque en un For, como en Validador Java - Fin -->
		
		
        <!-- Sumatoria IGV / ISC / Otros Tributos -->
        <xsl:if test="cac:TaxTotal/cbc:TaxAmount">
            <xsl:choose>
                <!-- INICIO DCERRENO -->
                <!-- <xsl:when test="not(string(cac:TaxTotal/cbc:TaxAmount]))">-->
                <xsl:when test="not(string((cac:TaxTotal/cbc:TaxAmount)[1]))">
                <!-- FIN DCERRENO -->
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2049)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <!-- INICIO DCERRENO -->
                    <!-- <xsl:if test='not(matches(cac:TaxTotal/cbc:TaxAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'> -->
                    <xsl:if test='not(matches((cac:TaxTotal/cbc:TaxAmount)[1],"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                    <!-- FINAL DCERRENO -->
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2048)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
            
            <xsl:for-each select="cac:TaxTotal">
                <xsl:if test='/Invoice/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000'>
                    <xsl:if test="count(./cbc:TaxAmount)>1">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2352)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
                <xsl:if test='/Invoice/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000'>
                    <xsl:if test="count(./cbc:TaxAmount)>1">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2353)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
                <xsl:if test='/Invoice/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=9999'>
                    <xsl:if test="count(./cbc:TaxAmount)>1">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2354)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
            </xsl:for-each>
            
        </xsl:if>
      
	    <!-- Validaciones TaxSchema -->
        <xsl:variable name="taxSubtotalTaxCategoryTaxScheme" select="(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme)[1]"/>
        <xsl:if test="$taxSubtotalTaxCategoryTaxScheme">
            <xsl:choose>
                <xsl:when test="not($taxSubtotalTaxCategoryTaxScheme/cbc:ID)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2052)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:if test='not(matches($taxSubtotalTaxCategoryTaxScheme/cbc:ID,"^[0-9]{4}$"))'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2050)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="not((($taxSubtotalTaxCategoryTaxScheme/cbc:ID)='1000') or (($taxSubtotalTaxCategoryTaxScheme/cbc:ID)='2000') or (($taxSubtotalTaxCategoryTaxScheme/cbc:ID)='9999'))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2051)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="not($taxSubtotalTaxCategoryTaxScheme/cbc:Name)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2054)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                <!--
                    <xsl:if test='not(matches($taxSubtotalTaxCategoryTaxScheme/cbc:Name,"^(?!\s*$)[^\s]{3,1000}"))'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2053)'"/>
                        </xsl:message>
                    </xsl:if>
                    -->
                </xsl:otherwise>
            </xsl:choose>
            <!-- Campo opcional, Antes expresion regular era ^(?!\s*$)[^\s]{3,100}$ -->
            <!-- INICIO DCERRENO -->
            <!--<xsl:if test='$taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode and not(matches($taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode,"^(\s*$)|(.*)?[^\s]{3,100}"))'>-->
            <!-- FINAL DCERRENO -->
            <xsl:if test='$taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode and not(matches($taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode,"^{3,100}"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2055)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:if test="(($taxSubtotalTaxCategoryTaxScheme/cbc:ID=1000) and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode !='' and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode and not($taxSubtotalTaxCategoryTaxScheme/cbc:Name='IGV'))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2057)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:if test="(($taxSubtotalTaxCategoryTaxScheme/cbc:ID=1000) and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode !='' and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode and not($taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode='VAT'))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2057)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:if test="(($taxSubtotalTaxCategoryTaxScheme/cbc:ID=2000) and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode !='' and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode and not($taxSubtotalTaxCategoryTaxScheme/cbc:Name='ISC'))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2058)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:if test="(($taxSubtotalTaxCategoryTaxScheme/cbc:ID=2000) and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode !='' and $taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode and not($taxSubtotalTaxCategoryTaxScheme/cbc:TaxTypeCode='EXC'))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2058)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:if>
        <!-- fin Validaciones TaxSchema -->
        
		<xsl:if test="/Invoice/cac:TaxTotal/cac:TaxSubtotal/cbc:TaxAmount">
            <xsl:for-each select="cac:TaxTotal">
                <xsl:choose>
                    <xsl:when test="not(string(./cac:TaxSubtotal/cbc:TaxAmount))">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2060)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test='not(matches(./cac:TaxSubtotal/cbc:TaxAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2059)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:if test="number(./cac:TaxSubtotal/cbc:TaxAmount)!=number(./cbc:TaxAmount)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2061)'"/>
                    </xsl:message>
                </xsl:if>
                <xsl:if test="$sacSUNATTransactionID[text() = '04'] and (./cac:TaxSubtotal/cbc:TaxAmount[text()&lt;=0])">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2502)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:for-each>
        </xsl:if>
        
		<!-- TODO: quiza haga falta realizar un for-each Verificar con detenimiento 
			cac:PricingReference/cac:AlternativeConditionPrice -->
        <xsl:if test="(cbc:DocumentCurrencyCode!=$sacAdditionalInformation/sac:AdditionalMonetaryTotal/cbc:ID[text()!='2001']/../cbc:PayableAmount/@currencyID)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2071)'"/>
            </xsl:message>
        </xsl:if>
        <!-- Validacion no se encuentra en java	-->
        
		<!-- Valida que el numero de documento del adquirente existe y si es RUC 
			valida que conste de 11 caracteres numericos -->
        <xsl:choose>
            <xsl:when test="not(string(cac:AccountingCustomerParty/cbc:CustomerAssignedAccountID))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2014)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test="cac:AccountingCustomerParty/cbc:AdditionalAccountID[text()='6'] and not(matches(cac:AccountingCustomerParty/cbc:CustomerAssignedAccountID,'^[0-9]{11}$|^[-]{1}$'))">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular FACTURA (codigo: 2017)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
       
	   <!-- Firma Digital de Documento -->
     <!--
        <xsl:choose>
            <xsl:when test="not((cac:Signature/cbc:ID))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2076)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
            
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="not(cac:Signature/cac:SignatoryParty/cac:PartyIdentification/cbc:ID)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2079)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:if test="(cac:Signature/cac:SignatoryParty/cac:PartyIdentification/cbc:ID != cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2078)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:choose>
            <xsl:when test="not(cac:Signature/cac:SignatoryParty/cac:PartyName/cbc:Name)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2081)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
           
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(cac:Signature/cac:DigitalSignatureAttachment/cac:ExternalReference/cbc:URI)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2083)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
           </xsl:otherwise>
        </xsl:choose>
		<xsl:choose>
            <xsl:when test="not((ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/@Id))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2085)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:CanonicalizationMethod/@Algorithm)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2087)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:SignatureMethod/@Algorithm)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2089)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:Reference/@URI)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2091)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='string(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:Reference/@URI)'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2090)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:Reference/ds:Transforms/ds:Transform/@Algorithm)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2093)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
           </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:Reference/ds:DigestMethod/@Algorithm)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2095)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
            
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignedInfo/ds:Reference/ds:DigestValue)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2097)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
			</xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignatureValue)">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2099)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:SignatureValue,"[A-Za-z0-9+/=\s]{2,}"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2098)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:KeyInfo/ds:X509Data/ds:X509Certificate)">
               <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2101)'"/>
                </xsl:message>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test='not(matches(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/ds:Signature/ds:KeyInfo/ds:X509Data/ds:X509Certificate,"[A-Za-z0-9+/=\s]{2,}"))'>
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2100)'"/>
                    </xsl:message>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
		-->
				
		<!--27/10/2015-Maguilar - Exportacion con operaciones gratuitas (Global)/ inicio -->
			<!--COND: Identifica que se trata de una operacion de exportacion -->
			<xsl:if test="$sacSUNATTransactionID[text()='02']">
					<!--COND: si e la operacion de exportacion hay al menos un item marcado como gratuito -->
					<xsl:if test="count(cac:InvoiceLine[cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode='02'])>0">
					<!--VAL 4: Informacion Adicional - Otros conceptos tributarios  Catálogo No. 14 / Valor 1004  de venir y este debe ser mayor a 0-->
						<xsl:if test="number(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal[cbc:ID=1004]/cbc:PayableAmount) = 0
						or not(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal[cbc:ID=1004]/cbc:PayableAmount)"> 
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Operacion gratuita,  debe consignar Total valor venta - operaciones gratuitas  mayor a cero (codigo: 2641)'"/>
							</xsl:message>			
						</xsl:if>	
					</xsl:if>
			</xsl:if>
		<!--27/10/2015-Exportacion con operaciones gratuitas / fin -->		
		
		<!--27/10/2015-Maguilar - IVAP / inicio -->
		<!--COND: Para un tipo de operacion IVAP -->
		<xsl:if test="ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:SUNATTransaction/cbc:ID=07">
			<!--VAL 1:Todo Item debe tener impuesto>0  , para ello se cuentan todos los items que tengan 0 en monto -->
			<!--ERR: Debe consignar Monto de impuestos-->
			<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cbc:TaxAmount=0])"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta IVAP debe consignar Monto de impuestos por item(codigo: 2643)'"/>
				</xsl:message>
			</xsl:if>
			<!--VAL 2:Todo Item debe tener codigo de afectacion en 17  , para ello se cuentan todos los items que sean diferentes de 17 -->
			<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode!=17])"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta IVAP solo debe tener ítems con código afectación IGV 17(codigo: 2644)'"/>
				</xsl:message>
			</xsl:if>
			<!--VAL 3:Todo Item debe tener codigo de afectacion en 17  y codigo tributo 1000 , para ello se cuentan todos los items que sean diferentes de 1000 -->
			<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID!=1000])"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta a IVAP debe consignar items con codigo de tributo 1000(codigo: 2645)'"/>
				</xsl:message>
			</xsl:if>
			<!--VAL 4:Todo Item debe tener codigo de afectacion en 17 y Tipo IVAP  , para ello se cuentan todos los items que sean diferentes de 1000 -->
			<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name!='IVAP'])"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta a IVAP debe consignar  items con nombre  de tributo IVAP(codigo: 2646)'"/>
				</xsl:message>			
			</xsl:if>
			<!--VAL 5:Todo Item debe tener Tipo de codigo de afectacion VAT , para ello se cuentan todos los items que sean diferentes de VAT -->
			<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode!='VAT'])"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Código tributo  UN/ECE debe ser VAT(codigo: 2647)'"/>
				</xsl:message>				
			</xsl:if>	
			<!--VAL 6:Total valor de venta - operaciones gravadas /Código de tipo de monto -  Catálogo No. 14 / Valor 1001  ** Se suman aquellos valores que sean diferentes de 1001-->
			<xsl:if test="sum(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal[cbc:ID!='1001']/cbc:PayableAmount)>0"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta al IVAP, solo puede consignar informacion para operacion gravadas(codigo: 2648)'"/>
				</xsl:message>				
			</xsl:if>
			<!--VAL 7:MOnto de IGV debe ser mayor que cero  -->
			<xsl:if test="sum(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal[cbc:ID=1001]/cbc:PayableAmount)=0"> 
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Operación sujeta al IVAP, debe consignar monto en total operaciones gravadas(codigo: 2649)'"/>
				</xsl:message>				
			</xsl:if>
			<!--VAL 8:Monto de ISC debe ser cero o no venir -->
			<xsl:if test="cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme[cbc:ID=2000]/../../cbc:TaxAmount>0">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta al IVAP , no debe consignar valor para ISC o debe ser 0(codigo: 2650)'"/>
				</xsl:message>				
			</xsl:if>	
			<!--VAL 9:Monto Leyenda debe ser 2007-->
			<xsl:if test="string(ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalProperty/cbc:ID)!='2007'">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Factura de operacion sujeta al IVAP , debe registrar mensaje 2007(codigo: 2651)'"/>
				</xsl:message>					
			</xsl:if>
		</xsl:if>
		<!--27/10/2015 - IVAP / fin -->		
		
		
		<!--27/10/2015-Maguilar - Exportacion de un no Domiciliado /Inicio-->
		<!-- Se probo que acepte IGV a nivel global y de item y es valido sin modificar
			 Por ello solo se agregan las restricciones puntuales para este caso 
			 La identificacoin de que se trata de un exportacion en este caso esta en funcion de las lineas -->
			<!--COND:Siempre que se tenga un item con 40 exportacion y 1000 IGV IVA -->
		<xsl:variable name="itemsExportacion" select="
			    cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode='40' 
			and cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID='1000' 
			and cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='IGV' 
			and cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='VAT']" />
			<xsl:if test="count($itemsExportacion)>0">
				<!--COND: Para los casos en los que el tipo de documento del adquiriente es 0 No domiciliado  -->
				<xsl:if test="cac:AccountingCustomerParty/cbc:AdditionalAccountID='0'"> 
					<!--VAL 2 :Los tipos de impuesto a utilizar deben ser Cod Trib 1000 -->
					<!--ERR : Exportacion de un no domiciliado - Todos los items deben ser marcados como exportacion cod 1000  -->
					<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID!='1000'])>0">  
					  <xsl:message terminate="yes" >
							<xsl:value-of select="'Servicios prestados No domiciliados. Código tributo a consignar debe ser 1000(codigo: 2654)'"/>
						</xsl:message>						
					</xsl:if>	
								
					<!--VAL 3 :Los tipos de impuesto a utilizar deben ser marcados como exportacion 40  -->
					<!--ERR Codigo de tributo no corresponde-->
					
					<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode!='40'])>0">  
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Servicios prestados No domiciliados.  El código de afectación debe ser 40(codigo: 2655)'"/>
						</xsl:message>										
					</xsl:if>
					
					<!--VAL 4 :Los tipos de impuesto a utilizar deben ser marcados Tipo codigo VAT  -->
					<!--ERR Codigo de tributo no corresponde-->
				
					<xsl:if test="count(cac:InvoiceLine[cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode!='VAT'])>0">  
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Servicios prestados No domiciliados. Código tributo  UN/ECE debe ser VAT (codigo: 2656)'"/>
						</xsl:message>		
					</xsl:if>

				</xsl:if>
			</xsl:if>			
		<!--27/10/2015 - Exportacion de un no Domiciliado/ fin -->		
		
        <!-- Detalle Factura -->
        <xsl:for-each select="/Invoice/cac:InvoiceLine">
			<!--27/10/2015-Maguilar - Exportacion con operaciones gratuitas (Item) / inicio -->
			<xsl:choose>
				<!--COND: Identifica que se trata de una operacion de exportacion a nivel de tipo de operacion-->
				<xsl:when test="$sacSUNATTransactionID[text()='02']">
					<!--COND: Si el tipo de linea es onerosa , porque asi lo indica el precio-->
					<!--VAL 1: El tipo de afectacion de IGV debe ser 40 para la exportacion sea o no un item gratuito-->
					<xsl:if test="cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text() != '40']">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Operaciones de exportacion, deben consignar Tipo Afectacion igual a 40 (codigo: 2642)'"/>
						</xsl:message>	
					</xsl:if>
					<!--COND: Si el tipo de linea es gratuita , porque asi lo indica el precio-->
					<xsl:if test='cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode = 02'>
						<!--VAL 2: Valor unitario : de las operaciones gratuitas debe ser cero -->
						<xsl:if test="cac:Price/cbc:PriceAmount>0"> 
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Operacion gratuita, solo debe consignar un monto referencial  (codigo: 2640)'"/>
							</xsl:message>
						</xsl:if>
					</xsl:if>
				</xsl:when>
			</xsl:choose>
			<!--27/10/2015-Maguilar - Exportacion con operaciones gratuitas (Item) / final -->
            <!-- Numero de orden del Item -->
            <xsl:choose>
                <xsl:when test="not(./cbc:ID)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2023)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:if test='not(matches(./cbc:ID,"^[0-9]{1,3}?$")) or ./cbc:ID &lt;= 0'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2023)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
            
			<!-- Cantidad de unidades por item -->
            <xsl:choose>
                <xsl:when test="not(string(./cbc:InvoicedQuantity))">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2024)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:if test='not(matches(./cbc:InvoicedQuantity,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
                        <!-- 17/09/2014 se corrigio la cantidad de decimales, decia 3 -->
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2025)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
			
            <!-- Descripcion detallada del servicio prestado, bien vendido o cedido en uso, indicando las caracteristicas -->
            <xsl:choose>
                <xsl:when test="not(./cac:Item/cbc:Description)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2026)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                <!--
                    <xsl:if test='not(matches(./cac:Item/cbc:Description,"^(?!\s*$).{1,250}"))'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2027)'"/>
                        </xsl:message>
                    </xsl:if>
                    -->
                </xsl:otherwise>
            </xsl:choose>
            <!-- Precio de venta unitario por item y codigo -->
            <!-- Realizar las validaciones dentro de un for-each cac:PricingReference/cac:AlternativeConditionPrice -->
            <xsl:for-each select="./cac:PricingReference/cac:AlternativeConditionPrice">
                <xsl:choose>
                    <xsl:when test="(./cbc:PriceTypeCode)=01 and (not(string(./cbc:PriceAmount)))">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2028)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test='(./cbc:PriceTypeCode)=01 and not(matches(./cbc:PriceAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
                            <!-- 17/09/2014 se corrigio la cantidad de decimales a 10 -->
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2367)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
                <!-- Precio de venta unitario por item -->
                <xsl:if test="(count(./cbc:PriceTypeCode[text()='01'])>1 or count(./cbc:PriceTypeCode[text()='02'])>1)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2409)'"/>
                    </xsl:message>
                </xsl:if>
                <xsl:if test="not(./cbc:PriceTypeCode=01 or ./cbc:PriceTypeCode=02)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2410)'"/>
                    </xsl:message>
                </xsl:if>
                <!-- actualizado 27/01/2014 fin -->
                <!-- Valor referencial unitario por item en operaciones no onerosas y codigo -->
                <xsl:choose>
                    <xsl:when test="(./cbc:PriceTypeCode)=02 and (not(string(./cbc:PriceAmount)))">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2417)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test='(./cbc:PriceTypeCode)=02 and not(matches(./cbc:PriceAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
                            <!-- 16/01/2014 se corrigio la cantidad de decimales, decia 10 lo correcto es 2 -->
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2408)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
             <xsl:choose>
                <xsl:when test="not(./cac:Price/cbc:PriceAmount)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="concat('Error Expr Regular Factura (codigo: 2068) line: ', cbc:ID)"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <!-- Valor unitario por item -->
                    <xsl:if test='matches(./cac:Price/cbc:PriceAmount,"^[\s]+$")'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="concat('Error Expr Regular Factura (codigo: 2067) line: ', cbc:ID)"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test='not(matches(./cac:Price/cbc:PriceAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="concat('Error Expr Regular Factura (codigo: 2369) line: ', cbc:ID)"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="not(./cbc:LineExtensionAmount)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2032)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <!-- Valor de venta por item -->
                    <xsl:if test='matches(./cbc:LineExtensionAmount,"^[\s]+$")'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2031)'"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test='not(matches(./cbc:LineExtensionAmount,"(-?[0-9]+){1,12}(\.[0-9]{1,2})?$"))'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2370)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
            <!-- Se incluye errores 2500 y 2501 en for-each - Inicio -->
            <xsl:if test="$sacSUNATTransactionID[text() = '04'] and (not(./cbc:LineExtensionAmount) or not(./cac:Item/cbc:Description))">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2500)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:if test="$sacSUNATTransactionID[text() = '04'] and (./cbc:LineExtensionAmount[text()&lt;=0])">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2501)'"/>
                </xsl:message>
            </xsl:if>
            <!-- Se incluye errores 2500 y 2501 en for-each - Fin -->
			
			<!-- Operaciones gratuitas aplicada a toda operacion gratuita-->					
			<xsl:if test="count(./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceAmount[text()>0 and parent::node()/cbc:PriceTypeCode=02])>0 
				and ./cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text() = '10' or text() = '20' or text() = '30']">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular Factura (codigo: 2425)'"/>
				</xsl:message>
			</xsl:if>			

            <!-- Afectacion al IGV por item - Sistema de ISC por item -->
            <!-- actualizado 16/01/2014 inicio -->
            <xsl:for-each select="/Invoice/cac:InvoiceLine/cac:TaxTotal">
                <xsl:if test='./cbc:TaxAmount'>
                    <xsl:choose>
                        <xsl:when test="not(string(./cbc:TaxAmount))">
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2034)'"/>
                            </xsl:message>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test='not(matches(./cbc:TaxAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                                <xsl:message terminate="yes" >
                                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2033)'"/>
                                </xsl:message>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:if test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 and count(./cbc:TaxAmount)>1">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2355)'"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000 and count(./cbc:TaxAmount)>1">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2356)'"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test="number(./cbc:TaxAmount)!=number(./cac:TaxSubtotal/cbc:TaxAmount)">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2372)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
                <xsl:choose>
                    <xsl:when test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID)">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2037)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID,"^[0-9]{4}$"))'>
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2035)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:if test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID[text()=1000 or text()=2000 or text()=9999])">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2036)'"/>
                    </xsl:message>
                </xsl:if>
                <xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000'>
                    <xsl:choose>
                        <xsl:when test="not(./cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode)">
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2371)'"/>
                            </xsl:message>
                        </xsl:when>
                        <xsl:otherwise>
							<xsl:if test="not(./cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text() = '10' or text() = '11' or text() = '12' or text() = '13' or text() = '14' or text() = '15' or text() = '16' or text() = '17' or text() = '20' or text() = '21' or text() = '30' or text() = '31' or text() = '32' or text() = '33' or text() = '34' or text() = '35' or text() = '36' or text() = '40'])">
                                <xsl:message terminate="yes" >
                                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2040)'"/>
                                </xsl:message>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
                <xsl:choose>
                    <xsl:when test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name)">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2038)'"/>
                        </xsl:message>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name,"^[A-Z]{3,1000}?$"))'>
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2038)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID'>
                    <xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000'>
                        <xsl:if test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name and ./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name !='' and (not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='IGV') and not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='VAT'))">
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2377)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:if>
                    <xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000'>
                        <xsl:if test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name and ./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name !='' and (not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='ISC') and not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='EXC'))">
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2378)'"/>
                            </xsl:message>
                        </xsl:if>
                    </xsl:if>
                </xsl:if>
                <xsl:if test="./cac:TaxSubtotal/cbc:TaxAmount">
                    <xsl:choose>
                        <xsl:when test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 and not(string(./cac:TaxSubtotal/cbc:TaxAmount))">
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2042)'"/>
                            </xsl:message>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test='not(matches(./cac:TaxSubtotal/cbc:TaxAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                                <xsl:message terminate="yes" >
                                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2368)'"/>
                                </xsl:message>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
                <xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000'>
                    <xsl:if test="not(string(./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange))  and ./cac:TaxTotal/cbc:TaxAmount > 0">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2373)'"/>
                        </xsl:message>
                    </xsl:if>
                    <xsl:if test="./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange and not(./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange[text()='' or text()=01 or text()=02 or text()=03])">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2041)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
            </xsl:for-each>
        </xsl:for-each>
        <!-- Sumatoria ISC error 2423 - Fin -->
        <!-- js _ RF07 Datos que permitan a la factura la posibilidad de traslado de bienes, según el reglamento de comprobantes vigentes _ Inicio -->
        <xsl:for-each select="$sacAdditionalInformation/sac:SUNATEmbededDespatchAdvice">
            <xsl:if test="$sacSUNATTransactionID[text() = '06']">
                <!-- a.1 + a.2 -->
                <xsl:variable name="todoNulo" select="not(./cac:DeliveryAddress/cbc:ID) and not(./cac:DeliveryAddress/cbc:StreetName) and not(./cac:DeliveryAddress/cbc:CityName) 
						and not(./cac:DeliveryAddress/cbc:CountrySubentity) and not(./cac:DeliveryAddress/cbc:District) and not(./cac:DeliveryAddress/cac:Country/cbc:IdentificationCode) 
						and not(./cac:OriginAddress/cbc:ID) and not(./cac:OriginAddress/cbc:StreetName) and not(./cac:OriginAddress/cbc:CityName) and not(./cac:OriginAddress/cbc:CountrySubentity) 
						and not(./cac:OriginAddress/cbc:District) and not(./cac:OriginAddress/cac:Country/cbc:IdentificationCode) "/>
                <xsl:if test="not($todoNulo)">
                    <xsl:if test="not(./cac:DeliveryAddress/cbc:ID != '' and ./cac:DeliveryAddress/cbc:StreetName != '' and ./cac:DeliveryAddress/cbc:CityName != '' 
							and ./cac:DeliveryAddress/cbc:CountrySubentity != '' and ./cac:DeliveryAddress/cbc:District != '' and ./cac:DeliveryAddress/cac:Country/cbc:IdentificationCode != '' 
							and ./cac:OriginAddress/cbc:ID != '' and ./cac:OriginAddress/cbc:StreetName != '' and ./cac:OriginAddress/cbc:CityName != '' and ./cac:OriginAddress/cbc:CountrySubentity != '' 
							and ./cac:OriginAddress/cbc:District != '' and ./cac:OriginAddress/cac:Country/cbc:IdentificationCode != '')">
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2421)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
                <!-- a.3	Debe de existir el tag de modalidad de transporte. 
					De no cumplir generar código de error 2532 - No existe información de modalidad de transporte. -->
                <xsl:if test="not(./cbc:TransportModeCode)">
                    <xsl:message terminate="no" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2532)'"/>
                    </xsl:message>
                </xsl:if>
                <!-- js_080715 a.4  El tag modalidad de transporte (cbc: TransportModeCode) debe ser = 01 o 02, de no cumplir generar código de  WARNING TEMPORAL EN LUGAR DE ERROR  4043 – Para el TransportModeCode, se está usando un valor que no existe en el catálogo Nro. 18. -->
                <xsl:if test="./cbc:TransportModeCode and ./cbc:TransportModeCode[text() != '01'] and ./cbc:TransportModeCode[text() != '02']">
                    <xsl:message terminate="no" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 4043)'"/>
                    </xsl:message>
                </xsl:if>
                <!-- a.5 Trasporte Privado cbc:TransportModeCode 02 -->
                <xsl:if test="./cbc:TransportModeCode and ./cbc:TransportModeCode[text() = '02']">
                    <!-- a.5.1 Debe existir los tags siguientes:
					-	Placa del vehículo
					-	N° constancia de inscripción del vehículo o certificado de habilitación vehicular
					-	Marca del vehículo
					-	Licencia de conducir
					De no cumplir generar código de error 2533 – Si ha consignado Transporte Privado, debe consignar Licencia de conducir, 
					Placa, N° constancia de inscripción y marca del vehículo.  -->
                    <xsl:variable name="Tags1" select="./sac:SUNATRoadTransport/cbc:LicensePlateID and ./sac:SUNATRoadTransport/cbc:TransportAuthorizationCode and ./sac:SUNATRoadTransport/cbc:BrandName and ./sac:DriverParty/cac:Party/cac:PartyIdentification/cbc:ID"/>
                    <xsl:if test="not($Tags1)">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2533)'"/>
                        </xsl:message>
                    </xsl:if>
                    <!-- a.5.2 No Debe existir los tags siguientes:
					-	RUC
					-	Nombre o Razón Social
					De no cumplir generar código de observación 4045 - No es necesario consignar los datos del transportista para la modalidad 
					de transporte 02 – Transporte Privado. -->
                    <xsl:if test="./sac:SUNATCarrierParty/cbc:CustomerAssignedAccountID and ./sac:SUNATCarrierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 4045)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
                <!-- a.6 Trasporte Publico cbc:TransportModeCode 01 -->
                <xsl:if test="./cbc:TransportModeCode and ./cbc:TransportModeCode[text() = '01']">
                    <!-- a.6.1 Debe existir los tags siguientes:
					-	RUC
					-	Nombre o Razón Social
					De no cumplir generar código de error 2534 – Si ha consignado Transporte púbico, debe consignar Datos del transportista. -->
                    <xsl:if test="not(./sac:SUNATCarrierParty/cbc:CustomerAssignedAccountID and ./sac:SUNATCarrierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName)">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2534)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
                <!-- a.7 cbc:GrossWeightMeasure -->
                <xsl:if test="./cbc:GrossWeightMeasure">
                    <!-- a.7.1   De existir el tag se debe validar que el campo @unitCode exista y tenga información.
					De no cumplir generar código de EXCEP 0306. -->
                    <xsl:if test="./cbc:GrossWeightMeasure/@unitCode and ./cbc:GrossWeightMeasure/@unitCode = ''">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 0306 - 1)'"/>
                        </xsl:message>
                    </xsl:if>
                    <!-- a.7.2  De existir el tag debe ser numerico, mayor a cero y como máximo tenga 2 decimales.
					De no cumplir generar código de error 2523 - GrossWeightMeasure – El dato ingresado no cumple con el formato establecido. -->
                    <xsl:if test="./cbc:GrossWeightMeasure &lt;= 0 or not(matches(./cbc:GrossWeightMeasure,'^[0-9]{1,12}(\.[0-9]{1,2})?$'))">
                        <xsl:message terminate="no" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2523)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:if>
            </xsl:if>
        </xsl:for-each>
        <xsl:if test="($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID=1002 
			and cac:InvoiceLine/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000) 
			and cac:InvoiceLine/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text()='10' or text()='20' or text()='30' or text()='40']">
            <xsl:message terminate="no" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 4025)'"/>
            </xsl:message>
        </xsl:if>
        <!-- Leyendas -->
        <xsl:if test="$sacAdditionalInformation/sac:AdditionalProperty/cbc:ID">
            <!--<xsl:if test='not(matches($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID,"^[^\s]{4}$"))'>-->
            <xsl:if test='not(matches(($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID)[1],"^[^\s]{4}$"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2366)'"/>
                </xsl:message>
            </xsl:if>
            <xsl:variable name="AdditionalPropertyId1000GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='1000'])>1"/>
            <xsl:variable name="AdditionalPropertyId1001GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='1001'])>1"/>
            <xsl:variable name="AdditionalPropertyId1002GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='1002'])>1"/>
            <xsl:variable name="AdditionalPropertyId2000GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='2000'])>1"/>
            <xsl:variable name="AdditionalPropertyId2001GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='2001'])>1"/>
            <xsl:variable name="AdditionalPropertyId2002GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='2002'])>1"/>
            <xsl:variable name="AdditionalPropertyId2003GreaterThan1" select="count($sacAdditionalInformation/sac:AdditionalProperty/cbc:ID[text()='2003'])>1"/>
            <xsl:if test="$AdditionalPropertyId1000GreaterThan1 or $AdditionalPropertyId1001GreaterThan1 or $AdditionalPropertyId1002GreaterThan1 or $AdditionalPropertyId2000GreaterThan1 or $AdditionalPropertyId2001GreaterThan1 or $AdditionalPropertyId2002GreaterThan1 or $AdditionalPropertyId2003GreaterThan1">
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2407)'"/>
                </xsl:message>
            </xsl:if>
        </xsl:if>
        <xsl:if test="$sacAdditionalInformation/sac:AdditionalProperty/cbc:Value">
        <!--
            <xsl:if test='not(matches($sacAdditionalInformation/sac:AdditionalProperty/cbc:Value,"^(?!\s*$).{1,100}"))'>
                <xsl:message terminate="yes" >
                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2066)'"/>
                </xsl:message>
            </xsl:if>
            -->
        </xsl:if>
        <!-- Se incluye bloque en un for-each como en Validador Java - Inicio -->
        <xsl:for-each select="$additionalMonetaryTotal">
            <xsl:choose>
                <xsl:when test="not(string(./cbc:ID))">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2046)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <!--
                    <xsl:variable name="respParametro">
                        <xsl:call-template name="parametro741">
                            <xsl:with-param name="codigo" select="./cbc:ID"/>
                        </xsl:call-template>
                    </xsl:variable>
                        -->
                    <!--
                    <xsl:choose>
                        <xsl:when test='gemfunc:is-blank($respParametro)'>
                            <xsl:message terminate="yes" >
                                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2045)'"/>
                            </xsl:message>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test="$sacSUNATTransactionID[text() = '04'] and (./cbc:ID[text() = '1001']) and (./cbc:PayableAmount[text()&lt;=0])">
                                <xsl:message terminate="yes" >
                                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2502)'"/>
                                </xsl:message>
                            </xsl:if>
                            <xsl:if test="(./cbc:ID[text() = '2005']) and (not(./cbc:PayableAmount) or not(matches(./cbc:PayableAmount,'^[0-9]{1,12}(\.[0-9]{1,2})?$')))">
                                <xsl:message terminate="yes" >
                                    <xsl:value-of select="'Error Expr Regular Factura (codigo: 2065)'"/>
                                </xsl:message>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                    -->
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
        <!-- Se incluye bloque en un for-each como en Validador Java - Fin -->
        <!-- Por lo menos deben de existir algunos los codigos -->
        <xsl:if test="not(($additionalMonetaryTotalID[text()='1001' or text()='1002' or text()='1003' or text()='1004' or text()='3001']))">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2047)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:if test="(count($additionalMonetaryTotalID[text()='1001'])>1)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2349)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:if test="(count($additionalMonetaryTotalID[text()='1002'])>1)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2350)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:if test="(count($additionalMonetaryTotalID[text()='1003'])>1)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2351)'"/>
            </xsl:message>
        </xsl:if>
        <!-- No deberian de haber duplicados -->
        <xsl:if test="(count($additionalMonetaryTotalID[text()='1001'])>1 or
				count($additionalMonetaryTotalID[text()='1002'])>1 or 
				count($additionalMonetaryTotalID[text()='1003'])>1 or 
				count($additionalMonetaryTotalID[text()='1004'])>1 or 
				count($additionalMonetaryTotalID[text()='3001'])>1)">
            <xsl:message terminate="yes" >
                <xsl:value-of select="'Error Expr Regular Factura (codigo: 2406)'"/>
            </xsl:message>
        </xsl:if>
        <xsl:for-each select="$additionalMonetaryTotal">
            <xsl:choose>
                <xsl:when test="not(./cbc:PayableAmount)">
                    <xsl:message terminate="yes" >
                        <xsl:value-of select="'Error Expr Regular Factura (codigo: 2044)'"/>
                    </xsl:message>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:if test='not(matches(./cbc:PayableAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
                        <xsl:message terminate="yes" >
                            <xsl:value-of select="'Error Expr Regular Factura (codigo: 2043)'"/>
                        </xsl:message>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
        <xsl:copy-of select="."/>
    </xsl:template>
    <xsl:template name="comprobante_anticipado">
	</xsl:template>
    <!-- Template recursivo para obtener acumulador prepaidPayment-->
    <!--
    <xsl:template name="getPrepaidPaymentAcum">
        <xsl:param name="Items"/>
        <xsl:variable name="Item1" select="$Items[1]"/>
        <xsl:variable name="RemainingItems" select="$Items[position() &gt; 1]"/>
        <xsl:variable name="acumulador" select="$Item1/cbc:PaidAmount"/>
        <xsl:choose>
            <xsl:when test="$RemainingItems">
                <xsl:if test="$Item1/cbc:PaidAmount and (matches($Item1/cbc:PaidAmount,'^[0-9]{1,12}(\.[0-9]{1,2})?$') and $Item1/cbc:PaidAmount &gt; 0 )">
                    <xsl:variable name="subAcum">
                        <xsl:call-template name="getPrepaidPaymentAcum">
                            <xsl:with-param name="Items" select="$RemainingItems"/>
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:value-of select="$acumulador + $subAcum"/>
                </xsl:if>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$acumulador"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    -->
    <!-- Template para busqueda de parametro 741 -->
    <!--
    <xsl:template name="parametro741">
        <xsl:param name="codigo"/>
        <xsl:variable name="descripcionParam" select="document('local:///sistemagem/catalogos/Catalogo741.xml')"/>
        <xsl:value-of select="$descripcionParam/catalogo741/item[@numero=$codigo]"/>
    </xsl:template>
    <func:function name="gemfunc:is-blank">
        <xsl:param name="data" select="''"/>
        <func:result select="matches($data,'^[\s]*$')"/>
    </func:function>
	-->

</xsl:stylesheet>